==> open-cluster-management-observability-model-5.12.2-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/RetentionConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RetentionConfigBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigBuilder>{
  public RetentionConfigBuilder() {
    this(false);
  }
  public RetentionConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new RetentionConfig(), validationEnabled);
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RetentionConfig(), validationEnabled);
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig instance) {
    this(fluent, instance, false);
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBlockDuration(instance.getBlockDuration()); 
    fluent.withDeleteDelay(instance.getDeleteDelay()); 
    fluent.withRetentionInLocal(instance.getRetentionInLocal()); 
    fluent.withRetentionResolution1h(instance.getRetentionResolution1h()); 
    fluent.withRetentionResolution5m(instance.getRetentionResolution5m()); 
    fluent.withRetentionResolutionRaw(instance.getRetentionResolutionRaw()); 
    this.validationEnabled = validationEnabled; 
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig instance) {
    this(instance,false);
  }
  public RetentionConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBlockDuration(instance.getBlockDuration()); 
    this.withDeleteDelay(instance.getDeleteDelay()); 
    this.withRetentionInLocal(instance.getRetentionInLocal()); 
    this.withRetentionResolution1h(instance.getRetentionResolution1h()); 
    this.withRetentionResolution5m(instance.getRetentionResolution5m()); 
    this.withRetentionResolutionRaw(instance.getRetentionResolutionRaw()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.RetentionConfig build() {
    RetentionConfig buildable = new RetentionConfig(fluent.getBlockDuration(),fluent.getDeleteDelay(),fluent.getRetentionInLocal(),fluent.getRetentionResolution1h(),fluent.getRetentionResolution5m(),fluent.getRetentionResolutionRaw());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RetentionConfigBuilder that = (RetentionConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-observability-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/RetentionConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RetentionConfigBuilder extends RetentionConfigFluentImpl<RetentionConfigBuilder> implements VisitableBuilder<RetentionConfig,RetentionConfigBuilder>{
  public RetentionConfigBuilder() {
    this(false);
  }
  public RetentionConfigBuilder(Boolean validationEnabled) {
    this(new RetentionConfig(), validationEnabled);
  }
  public RetentionConfigBuilder(RetentionConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RetentionConfigBuilder(RetentionConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RetentionConfig(), validationEnabled);
  }
  public RetentionConfigBuilder(RetentionConfigFluent<?> fluent,RetentionConfig instance) {
    this(fluent, instance, false);
  }
  public RetentionConfigBuilder(RetentionConfigFluent<?> fluent,RetentionConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBlockDuration(instance.getBlockDuration()); 
    fluent.withDeleteDelay(instance.getDeleteDelay()); 
    fluent.withRetentionInLocal(instance.getRetentionInLocal()); 
    fluent.withRetentionResolution1h(instance.getRetentionResolution1h()); 
    fluent.withRetentionResolution5m(instance.getRetentionResolution5m()); 
    fluent.withRetentionResolutionRaw(instance.getRetentionResolutionRaw()); 
    this.validationEnabled = validationEnabled; 
  }
  public RetentionConfigBuilder(RetentionConfig instance) {
    this(instance,false);
  }
  public RetentionConfigBuilder(RetentionConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBlockDuration(instance.getBlockDuration()); 
    this.withDeleteDelay(instance.getDeleteDelay()); 
    this.withRetentionInLocal(instance.getRetentionInLocal()); 
    this.withRetentionResolution1h(instance.getRetentionResolution1h()); 
    this.withRetentionResolution5m(instance.getRetentionResolution5m()); 
    this.withRetentionResolutionRaw(instance.getRetentionResolutionRaw()); 
    this.validationEnabled = validationEnabled; 
  }
  RetentionConfigFluent<?> fluent;
  Boolean validationEnabled;
  public RetentionConfig build() {
    RetentionConfig buildable = new RetentionConfig(fluent.getBlockDuration(),fluent.getDeleteDelay(),fluent.getRetentionInLocal(),fluent.getRetentionResolution1h(),fluent.getRetentionResolution5m(),fluent.getRetentionResolutionRaw());
    return buildable;
  }
  
}
